package com.nisum.ecomservice.service;

import com.nisum.ecomservice.model.User;
import com.nisum.ecomservice.repository.UserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.client.WebClient;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@Service
public class UserService {

    private WebClient webClient;

    @Autowired
    private UserRepository userRepository;

    public Flux<User> getUsers() {
        return userRepository.findAll();
    }

    public Mono<User> createUser(User user) {
        return userRepository.save(user);
    }

    public Mono<User> getUserbyEmail(String email){
        return userRepository.findUserbyEmail(email);
    }

    public Mono<Boolean> verifyToken(String token){
        return WebClient
                .builder()
                .build()
                .get()
                .uri("https://www.googleapis.com/oauth2/v3/tokeninfo?id_token={token}", token)
                .exchangeToMono(clientResponse -> {
                    if(clientResponse.statusCode().is2xxSuccessful()){
                        return Mono.just(Boolean.TRUE);
                    }else {
                        return Mono.just(Boolean.FALSE);
                    }
                });
    }
}

