import React, { Component } from 'react'

export default class ProductDetails extends Component {
    constructor(props) {
        super(props)
        this.state = {
            orderItemQuantity: 1,
        }
    }

    handleChange(type) {
        return e => {
            this.setState({ [type]: e.target.value })
        }
    }

    handleSubmit(e, product) {
        e.preventDefault();
        const newCart = Object.assign({}, {
            userId: this.props.user.currentUser.email,
            cartItems: JSON.parse(JSON.stringify(this.props.cart)) // JSON.parse/stringify will deep-dup the object
        })
        for (let i = 0; i < newCart.cartItems.length; i++) {
            let item = newCart.cartItems[i];
            if(item.productRef.sku === product.sku) {
                item.quantity += parseInt(this.state.orderItemQuantity)
                this.props.addToCart(newCart, this.props.user.currentUser.email)
                    .then(() => this.props.closeModal(e))
                return;
            }
        }
        const newCartItem = {
            productRef: {
                id: product.sku,
                sku: product.sku,
                upc: product.upc,
            },
            quantity: parseInt(this.state.orderItemQuantity)
        }
        newCart.cartItems.push(newCartItem);
        this.props.addToCart(newCart, this.props.user.currentUser.email)
        .then(() => this.props.closeModal(e))
    }
    
    render() {
        return (
            <div className="product-details-container">
                <div id="product-details-left">
                    <div id="prod-details-container">
                        {
                            this.props.product.productImageUrl ?
                            <img alt="" src={ this.props.product.productImageUrl } id="prod-details-img" />
                            :
                            <div id="prod-details-no-img">
                                <p id="prod-details-no-image-display">- No Photo Available -</p>
                            </div>
                        }
                        <div id="prod-details-box">
                            <div id="details-brand-and-sku-box">
                                <p id="details-brand">{ this.props.product.brand }</p>
                                <p id="details-sku">sku: { this.props.product.sku }</p>
                            </div>
                            <p id="details-title">{ this.props.product.productName }</p>
                            <p id="details-description">{ this.props.product.productDescription }</p>
                        </div>
                    </div>
                </div>
                <div id="product-details-right">
                    <div id="product-details-condenser">
                        <div id="prod-details-shipping">
                            <p id="express-shipping">Express shipping & free returns</p>
                            <p id="free-delivery">Free Delivery: <span>Everywhere!</span></p>
                            <p id="get-it-by">Get it by: <span>Never!</span></p>
                        </div>
                        {
                            this.props.product.promo ? 
                            <div>
                                <p id="prod-details-promo-percentage">This is currently { this.props.product.promo }% off!</p>
                                <p id="prod-details-promo-discount-number">Buy now for ${ this.props.discount }</p>
                                <p id="prod-details-promo-original-price">Normally: ${ this.props.product.price }</p>
                            </div>
                            :
                            <p id="prod-details-original-price">Price: ${ this.props.product.price }</p>
                        }
                        <form className="details-add-cart-and-quantity" onSubmit={ e => this.handleSubmit(e, this.props.product) }>
                            <input 
                                type="number" 
                                className="prod-details-quantity"
                                id={ this.props.user?.currentUser ? "" : "disabled" }
                                disabled={ !this.props.user?.currentUser } 
                                onChange={this.handleChange("orderItemQuantity")}
                                placeholder="Quantity" 
                                value={ this.state.orderItemQuantity }
                            />
                            <button 
                                className="prod-details-add-to-cart" 
                                id={ this.props.user?.currentUser ? "" : "disabled" }
                                disabled={ !this.props.user?.currentUser
                            }>Add to Cart</button>
                            { this.props.user?.currentUser ? "" :<p id="details-please-log-in-notice">Log in to Add to Cart</p>}
                        </form>
                        </div>
                </div>
            </div>
        )
    }
}
