import React, { Component } from 'react'
import { GoogleLogin, GoogleLogout } from 'react-google-login';
import '../../resources/stylesheets/session.css'

const clientId = `${process.env.REACT_APP_GOOGLE_CLIENT_ID}.apps.googleusercontent.com`;

export default class Session extends Component {
    constructor(props) {
        super(props)

        this.state = {
            logIn: false
        }

        this.loginSuccess = this.loginSuccess.bind(this)
        this.loginFailed = this.loginFailed.bind(this)
        this.logOutSuccess = this.logOutSuccess.bind(this)
    }

    loginSuccess = (response) => {
        const {accessToken, tokenId, googleId: userId, profileObj} = response
        const {email, familyName: lastName, givenName: firstName} = profileObj
        const userResponse = {idToken: tokenId, userId, email, firstName, lastName, accessToken}
        this.props.login(userResponse)
        this.setState({logIn: true})
        
        // try grabbing user cart
        this.props.getUserCart(email)
            .then(res => res.json)
            .catch(err => {
                const newCart = {
                    userId: email,
                    cartItems: []
                }
                this.props.createCart(newCart)
            })
    }

    loginFailed = (response) => {
        // console.log('Login failed: res:', response);
        return response
    }

    logOutSuccess = (response) => {
        this.props.logOut()
        this.props.clearCart()
        this.setState({logIn: false})
    }
    
    render() {
        return (
            <div className="google-login-button">
                {!this.state.logIn ? 
                    <GoogleLogin
                        clientId={clientId}
                        buttonText="Login"
                        onSuccess={this.loginSuccess}
                        onFailure={this.loginFailed}
                        cookiePolicy={'single_host_origin'}
                /> :  <GoogleLogout
                        clientId={clientId}
                        buttonText="Logout"
                        onLogoutSuccess={this.logOutSuccess}
                    ></GoogleLogout>
                }
            </div>
        )
    }
}
